@@ -12,7 +12,7 @@ class TacviewCli:
         parser = argparse.ArgumentParser(
             description='Tacview-Client CLI',
             usage="Run one of: [client, createdb dropdb]")
-        parser.add_argument('command', choices= ['client', 'serve', 'dropdb', 'createdb'],
+        parser.add_argument('command', choices= ['client', 'dropdb', 'createdb'],
                             help='Subcommand to invoke')
         args = parser.parse_args(sys.argv[1:2])
         if not hasattr(self, args.command):
