@@ -154,20 +154,23 @@ def create_tables():
                     id AS impact_id,
                     weapon_first_time, weapon_last_time, session_id,
                     round(cast(impact_dist as numeric), 2) impact_dist,
-                    ROUND(cast(weapon_last_time - weapon_first_time as numeric), 2) kill_duration
+                    ROUND(cast(weapon_last_time - weapon_first_time as numeric), 2) kill_duration,
+                    weapon_color, target_color, killer_color
                 FROM  impact
                 INNER JOIN (SELECT id killer, pilot killer_name, name killer_type,
-                            start_time
+                            start_time, color killer_color
                             FROM object
                             INNER JOIN (select session_id, start_time FROM session) sess2
 			                USING (session_id)) kill
                 USING (killer)
-                INNER JOIN (SELECT id target, pilot as target_name, name as target_type
+                INNER JOIN (SELECT id target, pilot as target_name, name as target_type,
+                            color target_color
                             FROM object) tar
                 USING(target)
                 INNER JOIN (SELECT id weapon, name AS weapon_name,
                                 first_seen as weapon_first_time,
-                                last_seen AS weapon_last_time, weapon_type
+                                last_seen AS weapon_last_time, weapon_type,
+                                color weapon_color
                             FROM object
                             LEFT JOIN (SELECT name, category AS weapon_type
                                        FROM weapon_types) weap_type
